; #####################################################################################################
; Shorcuts to the most used applications or folders
; #####################################################################################################
; If you don't remember what you've set on the different Hotkeys, you could hit those keys to see each
; panel of hotkeys on a message box
; CTRL + BackSpace
; ALT + BackSpace
; WIN + BackSpace
; ALTGR + BackSpace
; CTRL WIN + BackSpace
; CTRL ALT + BackSpace

; #####################################################################################################
; If you want to keep this file clear/clean and easy to understand. Plus you'll be able to access ALL
; your favorite programs and folders easily, here's a trick.
; 
; I won't talk about the need to store your data on a different drive as "C:" so...
; First create the "D:\myDocuments\myShortcuts" folder. In this folder you'll store links to
; your most used programs or folders. And give them a short and easy to understand name like:
; "FreeDownloadManager" linking to "D:\Programs\Free Download Manager\fdm.exe"
; or "Images" linking to "F:\[Backup]\Images"
; or "Song" linking to "F:\[Backup]\Songs\lyrics.txt"
;
; Press "Win + pause" to open the Control Panel, in the "advanced tab" click on "Environment Variables".
; Create a New User Variable named "Path" and valued as "D:\myDocuments\myShortcuts".
; nb: you can insert more folders by seperating them with a semicolon
; "D:\myDocs\Shortcuts\myFolders;D:\myDocs\Shortcuts\mySoftware;D:\myDocs\Shortcuts\myFiles".
; Confirm it by pressing "OK" back to the Control Panel.
;
; After rebooting, you should be able to access your links through the Run window.
; Press "Win + R" and fill in the name of one shortcut from the "myShortcuts" folder.
; Try "FreeDownloadManager" or "Images" or "Song" without quotation marks to see if that works.
;
; Now you are ready to edit the "NumpadShortcuts.ini" document.
; Edit the lines from Numpad0 to NumpadAdd in the 5 different groups.
; i.e. #Numpad3::Run theNameOfYourFavoriteShortcut
;
; Enjoy...
; Vince from http://www.vincent.max.st
; Juil 17, 2008
; version 0.2
;
; #####################################################################################################
#SingleInstance, Force
; link to the "ini" file
iniFile = NumpadShortcuts.ini

; #####################################################################################################
; This function displays a string in an OSD type message
dspOSDMsg(dspType, dspTxt)
{
	; if a box is already displayed, kill it
	Gui Destroy

	; displays a box with some message in it
	; "dspType" value must be 0 or 1
	; 0 - the box will be in the middle of the screen
	; 1 - the box will have custom x and y coords (customX, customY)
	; "dspTxt" is the text to display

	; configure variables
	bgrndColor = black
	txtColor = cWhite
	txtStyle = s10
	txtFont = Courier New
	customX := 0
	customY := A_ScreenHeight-60

	; customizing the message box
	Gui +LastFound +AlwaysOnTop -Caption +ToolWindow
	Gui, Color, %bgrndColor%
	Gui, Font, %txtStyle%, %txtFont%
	Gui, Add, Text, %txtColor%, %dspTxt%
	if dspType
	{
		Gui, Show, x%customX% y%customY% NoActivate
	} else {
		Gui, Show, NoActivate
	}

	; wait for a moment then kill the message box
	Sleep, 2000
	Gui Destroy
}
; This function displays in a list what you have set on each numpad key (ini file)
infoReminder(iniFile, key)
{
	; displays a hotkey on each line and the ription for each one
	; Ctrl + [3]     Foobar2000 - next
	Keys = 0,1,2,3,4,5,6,7,8,9,div,mult,sub,add,dot,Ins,End,Down,PgDn,Left,Clear,Right,Home,Up,Pgup,Del,Enter
	Loop, Parse, Keys, `,
	{
		IniRead, value, %iniFile%, %key%, %A_LoopField%
		scText := scText "[" A_LoopField "]`t" value "`n"
	}
	; if you better like having an OSD type Msg
	;dspOSDMsg(0, scText)
	; if you better like having a MsgBox with an ok button
	scTitle := key " + ?"
	MsgBox,, %scTitle%, %scText%
}
; This function executes a hotkey and displays what's executed
appHotKey(iniFile, section, key)
{
	; we need to find out wich char has been hit
	; so we are looking for the string "Numpad"
	; and erase everything except the chars after that string
	stf = Numpad
	StringGetPos, pos, key, %stf%
	StringTrimLeft, key, key, pos+6

	; now we need to match with vars within the ini file
	IniRead, valueVar, %iniFile%, %section%, %key%
	if (valueVar = "")
	{
		Msg = This Hotkey is not binded (yet)
	} else {
		Msg := valueVar
		Run %valueVar%, max
	}
	dspOSDMsg("1", Msg)
}

; #####################################################################################################
; All the keys to bind from the numpad
Keys = Numpad0,Numpad1,Numpad2,Numpad3,Numpad4,Numpad5,Numpad6,Numpad7,Numpad8,Numpad9,NumpadDiv,NumpadMult,NumpadSub,NumpadAdd,NumpadDot,NumpadHome,NumpadEnd,NumpadUp,NumpadDown,NumpadLeft,NumpadRight,NumpadPgup,NumpadPgDn,NumpadDel,NumpadIns,NumpadClear,NumpadEnter
Loop, Parse, Keys, `,
{
; hotkeys
Hotkey, ^%A_LoopField%, Ctrl, On
Hotkey, #%A_LoopField%, Win, On
Hotkey, !%A_LoopField%, Alt, On
Hotkey, <^>!%A_LoopField%, AltGr, On
Hotkey, ^#%A_LoopField%, CtrlWin, On
Hotkey, ^!%A_LoopField%, CtrlAlt, On
; get info
Hotkey, ^bs, infoCtrl, On
Hotkey, #bs, infoWin, On
Hotkey, !bs, infoAlt, On
Hotkey, <^>!bs, infoAltGr, On
Hotkey, ^#bs, infoCtrlWin, On
Hotkey, ^!bs, infoCtrlAlt, On
; special non Runable scripts
Hotkey, ^NumpadSub, Volume_Down, On
Hotkey, ^NumpadAdd, Volume_Up, On
}
return

Ctrl:
Win:
Alt:
AltGr:
CtrlWin:
CtrlAlt:
	appHotKey(iniFile, A_ThisLabel, A_ThisHotkey)
Return

infoCtrl:
infoWin:
infoAlt:
infoAltGr:
infoCtrlWin:
infoCtrlAlt:
	StringTrimLeft, keyLabel, A_ThisLabel, 4
	infoReminder(iniFile, keyLabel)
return
